@@ -199,7 +199,7 @@ class TTvec(object):
         """
         if not ( (isinstance(A, TTvec) and A.init) and \
                      ((isinstance(B,TTvec) and B.init) or isinstance(B, float)) ): 
-            raise NameError("TensorToolbox.multilinalg.add: TT not initialized correctly")
+            raise NameError("TensorToolbox.TTvec.add: TT not initialized correctly")
 
         if isinstance(A,TTvec) and isinstance(B,float):
             lscp = [ np.ones((1,sh)) for i,sh in enumerate(A.shape()) ]
@@ -207,7 +207,7 @@ class TTvec(object):
             CP = Candecomp( lscp )
             B = TTvec(CP,A.eps)
             if not B.init:
-                raise NameError("TensorToolbox.multilinalg.add: TT not initialized correctly")
+                raise NameError("TensorToolbox.TTvec.add: TT not initialized correctly")
             
         for i in range(len(A.TT)):
             if i == 0:
@@ -234,6 +234,11 @@ class TTvec(object):
         """
         A += -B
         return A
+
+    def __div__(A,B):
+        if not isinstance(B,float):
+            raise AttributeError("TensorToolbox.TTvec.div: Division implemented only for floats")
+        return (A * (1./B))
         
     def __mul__(A,B):
         """
@@ -258,10 +263,10 @@ class TTvec(object):
         if isinstance(A,TTvec) and isinstance(B,TTvec):
             # Hadamard product
             if not A.init or not B.init:
-                raise NameError("TensorToolbox.multilinalg.mul: TT not initialized correctly")
+                raise NameError("TensorToolbox.TTvec.mul: TT not initialized correctly")
             
             if A.shape() != B.shape():
-                raise NameError("""TensorToolbox.multilinalg.mul: A and B have different shapes\n
+                raise NameError("""TensorToolbox.TTvec.mul: A and B have different shapes\n
                                \t A.shape(): %s
                                \t B.shape(): %s""" % (A.shape(),B.shape()))
             
@@ -273,7 +278,7 @@ class TTvec(object):
 
         elif isinstance(B,float) and isinstance(A,TTvec):
             if not A.init:
-                raise NameError("TensorToolbox.multilinalg.mul: TT not initialized correctly")
+                raise NameError("TensorToolbox.TTvec.mul: TT not initialized correctly")
 
             A.TT[0] *= B
             return A
