@@ -174,7 +174,7 @@ class TensorWrapper():
             MPI_SUPPORT = False
         
         if self.__maxprocs != None and not MPI_SUPPORT:
-            warnings.warn("MPI is not supported on this machine. The program will run without it.", RuntimeWarning)
+            warnings.warn("TensorToolbox.TensorWrapper: MPI is not supported on this machine. The program will run without it.", RuntimeWarning)
         
     def set_store_object(self, store_object):
         self.store_object = store_object
