@@ -146,15 +146,42 @@ if (0 in RUNTESTS) or opt == 'c':
     else:
         print_fail("0.2 Tensor Test: TT sum by scalar", "TT[idx] + b = %e, Expected = %e" % (TTb[3,3,3],8.))
 
+    # Diff by scalar
+    CPa = DT.Candecomp([5.*np.ones((1,5)),np.ones((1,6)),np.ones((1,7))])
+    TTa = DT.TTvec(CPa,1e-13)
+    TTb = TTa - 3.
+    if np.abs(TTb[3,3,3] - 2.) < 1e-12:
+        print_ok("0.2 Tensor Test: TT diff by scalar")
+    else:
+        print_fail("0.2 Tensor Test: TT diff by scalar", "TT[idx] + b = %e, Expected = %e" % (TTb[3,3,3],2.))
+
+    # Mul by scalar
+    CPa = DT.Candecomp([5.*np.ones((1,5)),np.ones((1,6)),np.ones((1,7))])
+    TTa = DT.TTvec(CPa,1e-13)
+    TTb = TTa * 3.
+    if np.abs(TTb[3,3,3] - 15.) < 1e-12:
+        print_ok("0.2 Tensor Test: TT mul by scalar")
+    else:
+        print_fail("0.2 Tensor Test: TT mul by scalar", "TT[idx] + b = %e, Expected = %e" % (TTb[3,3,3],15.))
+
+    # Div by scalar
+    CPa = DT.Candecomp([15.*np.ones((1,5)),np.ones((1,6)),np.ones((1,7))])
+    TTa = DT.TTvec(CPa,1e-13)
+    TTb = TTa / 3.
+    if np.abs(TTb[3,3,3] - 5.) < 1e-12:
+        print_ok("0.2 Tensor Test: TT div by scalar")
+    else:
+        print_fail("0.2 Tensor Test: TT div by scalar", "TT[idx] + b = %e, Expected = %e" % (TTb[3,3,3],5.))
+
     # Sum
     C = TT + TT
-    if  C[DT.idxfold(nrows,T_idx[0]),DT.idxfold(ncols,T_idx[1])] == 2. * Dd[T_idx[0],T_idx[1]]:
+    if  C[DT.idxfold(nrows,T_idx[0]),DT.idxfold(ncols,T_idx[1])] - 2. * Dd[T_idx[0],T_idx[1]] <= np.spacing(1):
         print_ok("0.2 Tensor Test: TT sum")
     else:
         print_fail("0.2 Tensor Test: TT sum", "TT[idx] + TT[idx] = %.5f" % C[DT.idxfold(nrows,T_idx[0]),DT.idxfold(ncols,T_idx[1])])
 
     C = TT * TT
-    if  C[DT.idxfold(nrows,T_idx[0]),DT.idxfold(ncols,T_idx[1])] == Dd[T_idx[0],T_idx[1]]**2.:
+    if  C[DT.idxfold(nrows,T_idx[0]),DT.idxfold(ncols,T_idx[1])] - Dd[T_idx[0],T_idx[1]]**2. <= np.spacing(1):
         print_ok("0.3 Tensor Test: TT mul")
     else:
         print_fail("0.3 Tensor Test: TT mul", "TT[idx] * TT[idx] = %.5f" % C[DT.idxfold(nrows,T_idx[0]),DT.idxfold(ncols,T_idx[1])])
