@@ -37,7 +37,7 @@ import TensorToolbox.multilinalg as mla
 
 from SpectralToolbox import Spectral1D as S1D
 from SpectralToolbox import SpectralND as SND
-from UQToolbox import UncertaintyQuantification as UQ
+from UQToolbox import RandomSampling as RS
 
 import matplotlib.pyplot as plt
 from matplotlib import cm
@@ -494,7 +494,7 @@ if PLOTTING:
 # # Compute integral by MC
 # N = 10**4
 # dists = [ stats.uniform(loc=-1.,scale=2.) for i in range(d) ]
-# samples = UQ.lhc(N,d,dists)
+# samples = RS.lhc(N,d,dists)
 # lhc_res = np.zeros(N)
 # for i in range(N): lhc_res[i] = f(samples[i,:],params)
 # LHC_int = 1./float(N) * np.sum(lhc_res)
